from .cli import WPWatcherCLI
"""Main program if called with python3 -m wpwatcher"""
if __name__ == '__main__':
    WPWatcherCLI()